expo-deseats_fc-method: Exponentiate 'deseats' Forecasts

expo,deseats_fc-methodR Documentation

Exponentiate deseats Forecasts

Description

Exponentiate, i.e. as act of retransformation, (point and interval) forecasts obtained via the deseats package.

Usage

## S4 method for signature 'deseats_fc'
expo(object, ...)

Arguments

object

an object of class "deseats_fc".

...

currently without purpose; included for compatibility only.

Details

This function simply exponentiates point forecasts and bounds of interval forecasts within an object of class "deseats_fc". This does not have the option to account for potential biases in point forecasts. For this purpose, use the predict method directly with expo = TRUE and adjust.bias = TRUE.

Value

An object of class "deseats_fc" is returned.

Examples


est <- s_semiarma(log(EXPENDITURES), set_options(order_poly = 3))
fc <- predict(est, n.ahead = 8)
fc2 <- expo(fc)
fc2



deseats documentation built on March 16, 2026, 5:08 p.m.