show,deseats-method: Printing of deseats Function Results
Description
Print results of the function deseats.
Usage
# S4 method for deseats
show(object)
Value
The function returns NULL.
Arguments
- object
an object of class "deseats".
Details
After trend and seasonality in a time series have been estimated using the
function deseats, basic estimation results can be easily printed to
the console.