| show,deseats-method | R Documentation |
deseats Function ResultsPrint results of the function deseats.
## S4 method for signature 'deseats'
show(object)
object |
an object of class |
After trend and seasonality in a time series have been estimated using the
function deseats, basic estimation results can be easily printed to
the console.
The function returns NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.