| expo,deseats_fc-method | R Documentation |
deseats ForecastsExponentiate, i.e. as act of retransformation, (point and interval) forecasts
obtained via the deseats package.
## S4 method for signature 'deseats_fc'
expo(object, ...)
object |
an object of class |
... |
currently without purpose; included for compatibility only. |
This function simply exponentiates point forecasts and bounds of interval
forecasts within an object of class "deseats_fc". This does not
have the option to account for potential biases in point forecasts. For this
purpose, use the predict method directly with expo = TRUE and
adjust.bias = TRUE.
An object of class "deseats_fc" is returned.
est <- s_semiarma(log(EXPENDITURES), set_options(order_poly = 3))
fc <- predict(est, n.ahead = 8)
fc2 <- expo(fc)
fc2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.