| predict,s_semiarma-method | R Documentation |
Obtain point and interval forecasts based on fitted Seasonal Semi-ARMA models.
## S4 method for signature 's_semiarma'
predict(
object,
n.ahead = 1,
intervals = TRUE,
alpha = c(0.95, 0.99),
method = c("norm", "boot"),
bootMethod = c("simple", "advanced"),
npaths = 5000,
quant.type = 8,
expo = FALSE,
adjust.bias = TRUE,
...
)
object |
an object of class |
n.ahead |
a numeric vector of length one that represents the forecasting horizon; assume that |
intervals |
a logical vector of length one that indicates whether or not
forecasting intervals should be obtained; the default is |
alpha |
a numeric vector of variable length that indicates the confidence levels
at which to obtain forecasting intervals; the default is |
method |
a character vector that indicates the method used to obtain forecasting
intervals; available are theoretical intervals based on the assumption of normal
innovations ( |
bootMethod |
a character vector that allows the user to select a bootstrap
procedure for the forecasting intervals when |
npaths |
the number of paths to simulate, if the forecasting intervals are obtained via a bootstrap. |
quant.type |
the method to obtain sample quantiles from the simulated
forecasting errors; see also the argument |
expo |
a logical vector of length one; indicates whether the forecasting
results should be exponentiated at the end; the default is |
adjust.bias |
a logical vector of length one; indicates whether or not
the point forecasts should have a bias adjustment when simultaneously
|
... |
only for comparability with the standard |
Assume a Seasonal Semi-ARMA model was fitted using s_semiarma.
Pass the resulting object to this method, in order to obtain point and
interval forecasts.
If expo = TRUE and adjust.bias = TRUE, the point forecasts
will be exponentiated and adjusted for bias, so that the resulting forecasts
can be seen as mean forecasts on the exponentiated scale. Forecasting intervals
do not need such an adjustment. For expo = FALSE, no adjustment will be
done. Let y_{n+k} be the forecast on the log-scale (with n
as the number of observations and k as the forecast horizon). Under
method = "norm", we use
\exp{y_{n+k}}\exp{\sigma_h^2 / 2} as the bias-adjusted
point forecast, where \sigma_h^2 / 2 is the estimated
variance of the prediction error in accordance with the infinite-order
moving-average representation of the fitted ARMA model part.
For method = "boot", the sample mean of future simulated paths on
the exponentiated scale is obtained.
A list with the following elements is returned.
predthe obtained point forecasts.
intervthe obtained forecasting intervals.
obsthe observation series.
ts_namethe name of the observation series object.
Dominik Schulz (Research Assistant) (Department of Economics, Paderborn
University),
Author and Package Creator
xt <- log(EXPENDITURES)
est <- s_semiarma(xt)
predict(est, n.ahead = 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.